==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fbyte.h <==
// class soot.coffi.Instruction_byte

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5ff9461e894d883d soot_coffi_Instruction__5fbyte

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbyte_H_
#define _JC_soot_coffi_Instruction__5fbyte_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbyte$sub_refs	_jc_soot_coffi_Instruction__5fbyte$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	_jc_soot_coffi_Instruction__5fbyte$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$refs	_jc_soot_coffi_Instruction__5fbyte$refs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$nonrefs	_jc_soot_coffi_Instruction__5fbyte$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$object	_jc_soot_coffi_Instruction__5fbyte$object;

typedef const struct _jc_soot_coffi_Instruction__5fbyte$vmethods	_jc_soot_coffi_Instruction__5fbyte$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbyte$vtable	_jc_soot_coffi_Instruction__5fbyte$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbyte$vtype	_jc_soot_coffi_Instruction__5fbyte$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbyte$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jbyte);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fbyte$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fbyte$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fbyte$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyte$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyte$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbyte$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbyte$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyte$vmethods	soot_coffi_Instruction__5fbyte;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbyte$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbyte$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyte$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyte$refs {
    _jc_soot_coffi_Instruction__5fbyte$sub_refs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs {
	jbyte	arg__5fb;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyte$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	soot_coffi_Instruction__5fbyte;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbyte$object {
	_jc_soot_coffi_Instruction__5fbyte$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbyte$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbyte$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbyte$vtype _jc_soot_coffi_Instruction__5fbyte$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbyte, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbyte$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbyte_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fbyte.h <==
// class soot.coffi.Instruction_byte

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5ff9461e894d883d soot_coffi_Instruction__5fbyte

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbyte_H_
#define _JC_soot_coffi_Instruction__5fbyte_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbyte$sub_refs	_jc_soot_coffi_Instruction__5fbyte$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	_jc_soot_coffi_Instruction__5fbyte$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$refs	_jc_soot_coffi_Instruction__5fbyte$refs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$nonrefs	_jc_soot_coffi_Instruction__5fbyte$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbyte$object	_jc_soot_coffi_Instruction__5fbyte$object;

typedef const struct _jc_soot_coffi_Instruction__5fbyte$vmethods	_jc_soot_coffi_Instruction__5fbyte$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbyte$vtable	_jc_soot_coffi_Instruction__5fbyte$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbyte$vtype	_jc_soot_coffi_Instruction__5fbyte$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbyte$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fbyte$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fbyte$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fbyte$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyte$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbyte$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_Instruction__5fbyte$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbyte$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbyte$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbyte$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyte$vmethods	soot_coffi_Instruction__5fbyte;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbyte$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbyte$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyte$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyte$refs {
    _jc_soot_coffi_Instruction__5fbyte$sub_refs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs {
	jbyte	arg__5fb;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbyte$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	soot_coffi_Instruction__5fbyte;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbyte$object {
	_jc_soot_coffi_Instruction__5fbyte$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbyte$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbyte$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbyte$vtype _jc_soot_coffi_Instruction__5fbyte$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbyte, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbyte$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbyte_H_ */
